#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nothunks
version:              0.2.1.1
visibility:           public
id:                   nothunks-0.2.1.1-ApaP6NV6S5x6EksK1ifyMV
key:                  nothunks-0.2.1.1-ApaP6NV6S5x6EksK1ifyMV
license:              Apache-2.0
copyright:            2018-2024 Input Output Global Inc (IOG)
maintainer:           Marcin Szamotulski <coot@coot.me>
author:               IOG
synopsis:             Examine values for unexpected thunks
description:
    Long lived application data typically should not contain
    any thunks. This library can be used to examine values for
    unexpected thunks, which can then be used in assertions.
    This can be invaluable in avoiding memory leaks, or tracking
    down existing ones.

category:             Development
abi:                  3acdeaf4e3fcebe6ccf83a7ee6919284
exposed:              True
exposed-modules:      NoThunks.Class
import-dirs:          /usr/lib/ghc-9.6.6/site-local/nothunks-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/nothunks-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/nothunks-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nothunks
hs-libraries:         HSnothunks-0.2.1.1-ApaP6NV6S5x6EksK1ifyMV
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-heap-9.6.6
    stm-2.5.1.0 text-2.0.2 time-1.12.2
    vector-0.13.2.0-6bw5XgYHNiRDf00cbm2RSe
    wherefrom-compat-0.1.1.1-4rYXhQRxYU5Is1hp13xKR2

haddock-interfaces:   /usr/share/doc/haskell-nothunks/html/nothunks.haddock
haddock-html:         /usr/share/doc/haskell-nothunks/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

